/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Playsophy code.
 *
 * The Initial Developer of the Original Code is Playsophy
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *		Karl Guertin <grayrest@grayrest.com>
 *		James A. Overton <james@overton.ca>
 *		Christian Stocker (Bitflux)
 *		Paul Everitt
 *		David Palm
 *		Richard prescott
 *
 * ***** END LICENSE BLOCK ***** */

/**
@fileoverview

Mozile Commands

This file handles the mozileFormat and mozileCommand functions,
which do the work when buttons are pressed or menuitems selected.

*/

/********* Button/MenuItem Handling Functions *********/
/**
All sorts of editing format commands.

The formatting commands are generated from the MES file.
*/
function mozileFormat( commandName ) {
	if (!mozilePrefs.getBoolPref("mozile.onBool")) {return}

	var f = ["mozileCommands.js","mozileFormat"];
	mozileDebug(f,2,"Format command: "+commandName);
	
		// make sure Mozile is detected
	if(!mozileDetect()) {
		mozileDebug(f,0,"No selection for Mozile to edit!");
		return;
	}

		// if there is no entry in the array, throw an error
	var commandIndex = mozileMES.findByName(commandName, mozileTarget.document.mozileMES.commands)
	if(commandIndex<0) {
		alert('Command  "'+ commandName +'" not defined!');
	}
	var command = mozileTarget.document.mozileMES.commands[commandIndex];
	var name = command[0];
	var title = command[1];
	var tooltip = command[2];
	var icon = command[3];
	var type = command[6];
	var args = command[7];

	//Save current state for Undo/Redo.
	mozileDo(name);

	//Switch off caret to avoid flicker.
	mozilePrefs.setBoolPref('accessibility.browsewithcaret', false);
	switch(type)
	{
		/* General commands */
		case "setLinesContainer":
			mozileSelection.changeLinesContainerNS(args[0], args[1]);
			break;

		case "unformat":
			mozileSelection.removeLinesContainer();
			break;

		case "wrapText":
			mozileSelection.wrapTextNS(args[0], args[1]);
			break;

		case "toggleAttribute":
			mozileSelection.toggleAttribute(args[0], args[1], args[2]);
			break;

		/* XHTML Style commands */
		case "styleLines":
			mozileSelection.styleLines(args[0], args[1]);
			break;

		case "styleText":
			mozileSelection.styleText(args[0], args[1]);
			break;
			
		case "toggleStyle":
			mozileSelection.toggleTextStyle(args[0], args[1], args[2]);
			break;
			
		case "indent":
			mozileSelection.indentLines(args[0]);
			break;

		case "outdent":
			mozileSelection.outdentLines(args[0]);
			break;

		/* XHTML commands */
		case "toggleListLines":
			mozileSelection.toggleListLines(args[0], args[1]);
			break;
			
		case "indentLists":
			mozileSelection.indentLists();
			break;

		case "outdentLists":
			mozileSelection.outdentLists();
			break;

		case 'link':
			mozileLinkText();
			break;

		case "unlink":
			mozileSelection.clearTextLinks(true);
			break;

		case 'table':
			var rowno = prompt("number of rows");
			var colno = prompt("number of columns");
			var te = mozileTarget.documentCreateXHTMLTable(rowno, colno);
			if(!te)
				alert("Can't create table: invalid data");
			else
				mozileSelection.insertNode(te);
			break;

		case 'image': // need to replace with native file selection dialog
			mozileSelection.insertXHTMLImg();
			break;

		case 'hr': // This needs work. hr should not be inserted inside block level elements such as p, h1, etc.
			mozileSelection.insertXHTMLElement("hr");
			break;

		case 'x-element':
			mozileSelection.insertXHTMLElement(args[0]);
			break;
		
		case 'mozileCommand':
			mozileCommand(args[0]);
			break;

		case 'no-op':
			break;

			// if the command type hasn't been found, throw an error
		default:
			alert('Command type "'+ command[2] +'" not defined!');
			return;
		break;
	}
	mozilePrefs.setBoolPref('accessibility.browsewithcaret', true);
	mozileDetect();
	mozileUpdateDisplay();
	mozileMarkupInput();
}

/**
Mozile non-formatting commands.
This function is used for non-formatting commands
All of the behaviours are in here, or called from here.
*/
function mozileCommand(name) {
	var f = ["mozileCommands.js","mozileCommand"];
	mozileDebug(f,2,"Command: "+name);

		// These commands don't require an editable selection
	switch(name) {
		case "about":
			window.open("chrome://mozile/content/XUL/about.xul", "about", "modal,centerscreen,chrome,resizable=no");
			return;
		case "options":
			window.open("chrome://mozile/content/XUL/options.xul", "options", "modal,centerscreen,chrome,resizable=no");
			return;
		case "advanced":
			window.open("chrome://mozile/content/XUL/advanced.xul", "advanced", "modal,centerscreen,chrome,resizable=no");
			return;
		case "info":
			window.open("chrome://mozile/content/XUL/info.xul", "rsd", "modal,centerscreen,chrome,resizable=yes");
			return;
		case "demo":
			mozileOpen(MOZILEC.DEMO, "tab");
			return
		case "home":
			mozileOpen(MOZILEC.HOME, "tab");
			return;
		case "help":
			mozileOpen(MOZILEC.HELP, "tab");
			return;
	}
	
	if (!mozilePrefs.getBoolPref("mozile.onBool")) {
		return;
	}

	switch(name) {
		case "edit-page":
			mozileMakeDocumentEditable();
			return;
		case "bug":
			window.open("chrome://mozile/content/XUL/debugging.xul", "debugging", "centerscreen,chrome,resizable=yes");
			return;
		case "edit-source":
			mozileShowSourceView();
			return;
	}
	
	// The following commands do require an editable selection,
	// so make sure Mozile is detected
	if(!mozileDetect()) {
		return;
	}

	try {
		switch(name) {
			case "view-tags":
				mozileShowHideTags();
				break;
			case "save":
				window.open("chrome://mozile/content/XUL/save.xul", "save", "modal,centerscreen,chrome,resizable=yes");
				break;
			case 'undo':
				mozileUndo();
				break;
			case 'redo':
				mozileRedo();
				break;
			case 'copy':
				mozileCopy();
				break;
			case 'cut':
				mozileCut();
				break;
			case 'paste':
				mozilePaste();
				break;
			case "special-characters":
				mozileSpecialOpen( mozileGetCurrentTarget() );
				break;
		}
		mozileDetect();
		mozileUpdateDisplay();
	} catch(e) {
		mozileDebug(f,0,"\n\nCommand error: "+ name +" -->"+e); 
	}
}


function mozileLinkText()
{
	var l = mozileSelection.getLink();
	if ( l !== null ) {
		var win = window.openDialog("chrome://mozile/content/XUL/link.xul",
			"link", "chrome,modal,centerscreen,resizable=yes", l);
		if ( l !== null ) {
			mozileSelection.linkText( l );
		}
	}
}

